# # Reproducibility Package
# # 02.1 Data Analysis -Employment


## NON-BAYESIAN ESTIMATION
# REML--------------------

REML <- metagen(
  TE = `beta final`,
  seTE = `SE beta final`,
  studlab = Author,
  data = df_employment,
  sm = "MD",
  random = TRUE,
  common = FALSE,
  method.tau = "REML",
  method.random.ci = "HK",
  level = 0.95,
  level.ma  = 0.95,
  level.hetstat= 0.95,
  title = "REML"
)

# Calculate the weights for the plot
weights_random <- 100 * REML$w.random / sum(REML$w.random)

# Create a summary of the results
meta_summary_REML <- data.frame(
  Study = REML$studlab,
  Estimate = REML$TE,
  SE = REML$seTE,
  Lower_CI_95 = REML$lower,
  Upper_CI_95 = REML$upper,
  p_value = REML$pval,
  Weight_Random = round(weights_random, 2)  # Round to two decimal places
)

# Add a row with the overall result (Overall 95%)
meta_summary_REML[nrow(meta_summary_REML) + 1, ] <- c(
  "Average Effect",                        # Study
  REML$TE.random,                 # Estimate
  REML$seTE.random,               # SE
  REML$lower.random,              # Lower CI 95%
  REML$upper.random,              # Upper CI 95%
  REML$pval.random,              # p-value
  NA                                    # Weight (Overall has no weight)
)


## REML 90--------------------

REML_90 <- metagen(
  TE = `beta final`,
  seTE = `SE beta final`,
  studlab = Author,
  data = df_employment,
  sm = "MD",
  random = TRUE,
  common = FALSE,
  method.tau = "REML",
  method.random.ci = "HK",
  level = 0.90,
  level.ma  = 0.90,
  level.hetstat= 0.90,
  title = "REML"
)

# Calculate the weights for the plot
weights_random <- 100 * REML_90$w.random / sum(REML_90$w.random)

# Create a summary of the results
meta_summary_REML_90 <- data.frame(
  Study = REML_90$studlab,
  Estimate = REML_90$TE,
  SE = REML_90$seTE,
  Lower_CI_90 = REML_90$lower,
  Upper_CI_90 = REML_90$upper,
  p_value = REML_90$pval,
  Weight_Random = round(weights_random, 2)  # Round to two decimal places
)

# Add a row with the overall result (Overall 90%)
meta_summary_REML_90[nrow(meta_summary_REML_90) + 1, ] <- c(
  "Average Effect",                        # Study
  REML_90$TE.random,                 # Estimate
  REML_90$seTE.random,               # SE
  REML_90$lower.random,              # Lower CI 90%
  REML_90$upper.random,              # Upper CI 90%
  REML_90$pval.random,              # p-value
  NA                                    # Weight (Overall has no weight)
)
meta_summary_REML<-merge(meta_summary_REML, select(meta_summary_REML_90,c(Study,Lower_CI_90,Upper_CI_90)), by="Study")


#Generate excel file with BHM Estimates
write_xlsx(meta_summary_REML, file.path(path, "Outputs/Employment/REML_Employment.xlsx"))

## BAYESIAN ESTIMATION
# Baggr (Rachael Meager, Witold Wiecek)--------------------

df_employment<-read_excel(file.path(path, "Data/Intermediate/df_employment.xlsx"))
str(df_employment)

set.seed(426)  
fit <- baggr(df_employment, model = "rubin", pooling = "partial",
             prior_hypermean = normal(0, 100), 
             prior_hypersd = normal(0, 100),  # Usar normal para la SD
             iter = 5000, warmup = 3500,
             effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))


effects_summary <- data.frame(summary(fit$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary$Author<-fit$data$Author
effects_summary$Region<-fit$data$Region
effects_summary$Income_group<-fit$data$Income_group
effects_summary<-effects_summary %>% arrange(-mean)
over_all<-data.frame(summary(fit$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary<-bind_rows(effects_summary,over_all)
effects_summary$Author[nrow(effects_summary)] <- "Average Effect" 

#Generate excel file with BHM Estimates
write_xlsx(effects_summary, file.path(path, "Outputs/Employment/BHM_Employment.xlsx"))


# Open a graphics device (before creating the plot)
png(
  filename = file.path(path, "Outputs/Employment/fig1_forestplot_Employment.png"),
  width = 22.2,  # Width in inches
  height = 12.5,  # Height in inches 10.2
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

###### Figure 1: --------------------

# Generate the forest plot
# Prepare the data
mean_values <- effects_summary$mean
lower95 <- effects_summary$X2.5.
upper95 <- effects_summary$X97.5.

# Build the label table
tabletext <- cbind(
  c("Author", effects_summary$Author),
  c("Region", as.character(effects_summary$Region)),
  c("Estimate", sprintf("%.1f", mean_values)),
  c("95% CI", sprintf("[%.1f, %.1f]", lower95, upper95))
)

# Identify the Average Effect (mu[1])
is_summary <- c(TRUE, rep(FALSE, nrow(effects_summary)))

# Dynamically calculate the xticks
x_ticks <- seq(floor(min(effects_summary$X2.5., na.rm = TRUE) / 10) * 10,
               ceiling(max(effects_summary$X97.5., na.rm = TRUE) / 10) * 10,
               by = 10)

# Text and fonts
txt_size <- 1.4  # Uniform size for everything
forestplot(
  labeltext = tabletext,
  mean = cbind(c(NA, mean_values)),
  lower = cbind(c(NA, lower95)),
  upper = cbind(c(NA, upper95)),
  colgap = unit(c(20), "mm"),
  col = fpColors(
    box = c("#4682B4", "#A9A9A9"),
    lines = c("#4682B4", "#A9A9A9"),
    summary = "navy"
  ),
  
  boxsize = 0.2,
  lineheight = "auto",
  graphwidth = unit(20, "cm"), #17
  mar = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
  
  fn.ci_norm = rep(list(fpDrawCircleCI), nrow(effects_summary) + 1), # Corregido aquí
  ci.vertices = TRUE,
  ci.vertices.height = 0.25,
  
  txt_gp = fpTxtGp(
    label = gpar(cex = 1.7),
    ticks = gpar(cex = 1.2),
    xlab = gpar(cex = 1.5),
    title = gpar(cex = txt_size),
    legend = gpar(cex = txt_size)
  ),
  
  xlab = "Effect Size",
  zero = 0,
  is.summary = is_summary,
  xticks = x_ticks,
  grid = structure(effects_summary$mean[effects_summary$Author=='Average Effect'], gp = gpar(col = c("forestgreen"), lty = 2, lwd = 1.5)),
)

# Close the graphics device (after creating the plot)
dev.off()

#### 1. Sub group analysis ---------------

## 1.1 Guaranteed loan---------

table(df_employment$Type_loan)
# Filter data for "Guaranteed Loan"
df_employment_gl <- df_employment %>% filter(Type_loan == "Guaranteed")

set.seed(426) 
# Fit the model for "Guaranteed Loan" using baggr
fit_gl <- baggr(df_employment_gl, model = "rubin", pooling = "partial",
                prior_hypermean = normal(0, 100), 
                prior_hypersd = normal(0, 100),
                iter = 4500, warmup = 3000,
                effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))


# Summarize the effects for "Guaranteed Loan"
effects_summary_gl <- data.frame(summary(fit_gl$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_gl$Author <- fit_gl$data$Author

# Add Average Effects (mu and tau) correctly
over_all_gl <- data.frame(summary(fit_gl$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_gl <- bind_rows(effects_summary_gl, over_all_gl)

# Filter data for "Non-Guaranteed Loan"
df_employment_ngl <- df_employment %>% filter(Type_loan == "Non-Guaranteed")

set.seed(426) 
# Fit the model for "Non-Guaranteed Loan" using baggr
fit_ngl <- baggr(df_employment_ngl, model = "rubin", pooling = "partial",
                 prior_hypermean = normal(0, 100), 
                 prior_hypersd = normal(0, 100),
                 iter = 5000, warmup = 3500,
                 effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))

# Summarize the effects for "Non-Guaranteed Loan"
effects_summary_ngl <- data.frame(summary(fit_ngl$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_ngl$Author <- fit_ngl$data$Author

# Add Average Effects (mu and tau) correctly
over_all_ngl <- data.frame(summary(fit_ngl$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_ngl <- bind_rows(effects_summary_ngl, over_all_ngl)

# Label the types for clarity
over_all_gl$type <- "Guaranteed"
over_all_ngl$type <- "Non-Guaranteed"

# Combine results into a single dataframe
df_guarantee <- bind_rows(over_all_gl, over_all_ngl)
rownames(df_guarantee) <- NULL

## 1.2.1.  Quality: Above_Below_Median ---------

# Filter data for "Above Median"
df_employment_above <- df_employment %>% filter(Above_Below_Median == "Above")

set.seed(426) 
# Fit the model for "Above Median" using baggr
fit_above <- baggr(df_employment_above, model = "rubin", pooling = "partial",
                   prior_hypermean = normal(0, 100), 
                   prior_hypersd = normal(0, 100),
                   iter = 5000, warmup = 3500,
                   effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))

# Summarize the effects for "Above Median"
effects_summary_above <- data.frame(summary(fit_above$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_above$Author <- fit_above$data$Author

# Add Average Effects (mu and tau) correctly
overall_above <- data.frame(summary(fit_above$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)

# Filter data for "Below Median"
df_employment_below <- df_employment %>% filter(Above_Below_Median == "Below")

set.seed(426) 
# Fit the model for "Below Median" using baggr
fit_below <- baggr(df_employment_below, model = "rubin", pooling = "partial",
                   prior_hypermean = normal(0, 100), 
                   prior_hypersd = normal(0, 100),
                   iter = 5000, warmup = 3500,
                   effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))

# Summarize the effects for "Below Median"
effects_summary_below <- data.frame(summary(fit_below$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_below$Author <- fit_below$data$Author

# Add Average Effects (mu and tau) correctly
overall_below <- data.frame(summary(fit_below$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)

# Label the types for clarity
overall_above$type <- "Above Median"
overall_below$type <- "Below Median"

# Combine results into a single dataframe
df_median <- bind_rows(overall_above, overall_below)
rownames(df_median) <- NULL

## 1.2.2.  Quality: Above_Below_1500 ---------

# Filter data for "Above 1500"
df_employment_above_1500 <- df_employment %>% filter(Above_Below_1500 == "Above")

set.seed(426) 
# Fit the model for "Above 1500" using baggr
fit_above_1500 <- baggr(df_employment_above_1500, model = "rubin", pooling = "partial",
                        prior_hypermean = normal(0, 100), 
                        prior_hypersd = normal(0, 100),
                        iter = 5000, warmup = 3500,
                        effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))

# Summarize the effects for "Above 1500"
effects_summary_above_1500 <- data.frame(summary(fit_above_1500$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_above_1500$Author <- fit_above_1500$data$Author

# Add Average Effects (mu and tau) correctly
overall_above_1500 <- data.frame(summary(fit_above_1500$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)

# Filter data for "Below 1500"
df_employment_below_1500 <- df_employment %>% filter(Above_Below_1500 == "Below")

set.seed(426) 
# Fit the model for "Below 1500" using baggr
fit_below_1500 <- baggr(df_employment_below_1500, model = "rubin", pooling = "partial",
                        prior_hypermean = normal(0, 100), 
                        prior_hypersd = normal(0, 100),
                        iter = 5000, warmup = 3500,
                        effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))

# Summarize the effects for "Below 1500"
effects_summary_below_1500 <- data.frame(summary(fit_below_1500$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_below_1500$Author <- fit_below_1500$data$Author

# Add Average Effects (mu and tau) correctly
overall_below_1500 <- data.frame(summary(fit_below_1500$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)

# Label the types for clarity
overall_above_1500$type <- "Above 1500"
overall_below_1500$type <- "Below 1500"

# Combine results into a single dataframe
df_1500 <- bind_rows(overall_above_1500, overall_below_1500)
rownames(df_1500) <- NULL


## 1.3  Business Size: More than 10 Employees vs Up to 10 Employees ---------

# Filter data for "More than 10 Employees"
df_employment_large <- df_employment %>% filter(Firm_Size == "More than 10 Employees")

set.seed(426) 
# Fit the model for "More than 10 Employees" using baggr
fit_large <- baggr(df_employment_large, model = "rubin", pooling = "partial",
                   prior_hypermean = normal(0, 100), 
                   prior_hypersd = normal(0, 100),
                   iter = 5000, warmup = 3000,
                   effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))

# Summarize the effects for "More than 10 Employees"
effects_summary_large <- data.frame(summary(fit_large$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary_large$Author <- fit_large$data$Author

# Add Average Effects (mu and tau) correctly
over_all_large <- data.frame(summary(fit_large$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)

# Filter data for "Up to 10 Employees"
df_employment_small <- df_employment %>% filter(Firm_Size == "Up to 10 Employees")


set.seed(426) 
fit_small <- baggr(df_employment_small, model = "rubin", pooling = "partial",
                   prior_hypermean = normal(0, 100), 
                   prior_hypersd = normal(0, 100),
                   iter = 5000, warmup = 2500,
                   effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))

  # Summarize the effects for "Up to 10 Employees"
  effects_summary_small <- data.frame(summary(fit_small$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_small$Author <- fit_small$data$Author
  
  # Add Average Effects (mu and tau) correctly
  over_all_small <- data.frame(summary(fit_small$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
  
  # Label the types for clarity
  over_all_large$type <- "More than 10 Employees"
  over_all_small$type <- "10 or fewer Employees"
  
  # Combine results into a single dataframe
  df_size <- bind_rows(over_all_large, over_all_small)
  rownames(df_size) <- NULL


  ## 1.4 Income Group: High Income vs Non-High Income (Developing Countries) ---------
  
  # Filter data for "High Income"
  df_employment_high <- df_employment %>% filter(IncomeF == "High income")
  
  # Fit the model for "High Income" using baggr
  set.seed(426) 
  fit_high <- baggr(df_employment_high, model = "rubin", pooling = "partial",
                    prior_hypermean = normal(0, 100), 
                    prior_hypersd = normal(0, 100),
                    iter = 5000, warmup = 3500,
                    effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))
  
  # Summarize the effects for "High Income"
  effects_summary_high <- data.frame(summary(fit_high$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_high$Author <- fit_high$data$Author
  
  # Add Average Effects (mu and tau) correctly
  over_all_high <- data.frame(summary(fit_high$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
  
  # Filter data for "Non-High Income"
  df_employment_nonhigh <- df_employment %>% filter(IncomeF == "Non-High income")
  
  # Fit the model for "Non-High Income" using baggr
  set.seed(426) 
  fit_nonhigh <- baggr(df_employment_nonhigh, model = "rubin", pooling = "partial",
                       prior_hypermean = normal(0, 100), 
                       prior_hypersd = normal(0, 100),
                       iter = 5000, warmup = 3500,
                       effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))
  
  # Summarize the effects for "Non-High Income"
  effects_summary_nonhigh <- data.frame(summary(fit_nonhigh$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_nonhigh$Author <- fit_nonhigh$data$Author
  
  # Add Average Effects (mu and tau) correctly
  over_all_nonhigh <- data.frame(summary(fit_nonhigh$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
  
  # Label the types for clarity
  over_all_high$type <- "High-income"
  over_all_nonhigh$type <- "Developing"
  
  
  # Combine results into a single dataframe
  df_income <- bind_rows(over_all_high, over_all_nonhigh)
  rownames(df_income) <- NULL
  

  ## 1.5.1 Private vs Public Financial Institutions ---------
  
  # Filter data for "Private Financial Institutions"
  df_employment_private <- df_employment %>% filter(Lender_type == "Private")
  
  # Fit the model for "Private Financial Institutions" using baggr
  set.seed(426) 
  fit_private <- baggr(df_employment_private, model = "rubin", pooling = "partial",
                       prior_hypermean = normal(0, 100), 
                       prior_hypersd = normal(0, 100),
                       iter = 5000, warmup = 3000,
                       effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))
  
  # Summarize the effects for "Private Financial Institutions"
  effects_summary_private <- data.frame(summary(fit_private$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_private$Author <- fit_private$data$Author
  
  # Add Average Effects (mu and tau) correctly
  over_all_private <- data.frame(summary(fit_private$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
  
  # Filter data for "Public Financial Institutions"
  df_employment_public <- df_employment %>% filter(Lender_type ==  "Public")
  
  # Fit the model for "Public Financial Institutions" using baggr
  set.seed(426) 
  fit_public <- baggr(df_employment_public, model = "rubin", pooling = "partial",
                      prior_hypermean = normal(0, 100), 
                      prior_hypersd = normal(0, 100),
                      iter = 5000, warmup = 3000,
                      effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))
  
  # Summarize the effects for "Public Financial Institutions"
  effects_summary_public <- data.frame(summary(fit_public$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_public$Author <- fit_public$data$Author
  
  # Add Average Effects (mu and tau) correctly
  over_all_public <- data.frame(summary(fit_public$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
  
  # Label the types for clarity
  over_all_private$type <- "Private"
  over_all_public$type <- "Public"
  
  # Combine results into a single dataframe
  df_lender <- bind_rows(over_all_private, over_all_public)
  rownames(df_lender) <- NULL
  
  ## 1.5.2 Private vs Public Funding Sources ---------
  
  table(df_employment$Funding_source)
  
  # Filter data for Private funding
  df_employment_private <- df_employment %>% 
    filter(Funding_source == "Private")
  
  # Fit the model for Private funding using baggr
  set.seed(426) 
  fit_private <- baggr(df_employment_private, 
                       model = "rubin", 
                       pooling = "partial",
                       prior_hypermean = normal(0, 100), 
                       prior_hypersd = normal(0, 100),
                       iter = 5000, 
                       warmup = 3000,
                       effect = "MD", 
                       control = list(adapt_delta = 0.999, max_treedepth = 15))
  
  # Summarize the effects for Private funding
  effects_summary_private <- data.frame(summary(fit_private$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_private$Author <- fit_private$data$Author
  
  # Add Average Effects (mu and tau)
  over_all_private <- data.frame(summary(fit_private$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
  
  # Filter data for Public funding
  df_employment_public <- df_employment %>% 
    filter(Funding_source == "Public")
  
  # Fit the model for Public funding using baggr
  set.seed(426) 
  fit_public <- baggr(df_employment_public, 
                      model = "rubin", 
                      pooling = "partial",
                      prior_hypermean = normal(0, 100), 
                      prior_hypersd = normal(0, 100),
                      iter = 5000, 
                      warmup = 3000,
                      effect = "MD", 
                      control = list(adapt_delta = 0.999, max_treedepth = 15))
  
  # Summarize the effects for Public funding
  effects_summary_public <- data.frame(summary(fit_public$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_public$Author <- fit_public$data$Author
  
  # Add Average Effects (mu and tau)
  over_all_public <- data.frame(summary(fit_public$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
  
  # Label the types for clarity
  over_all_private$type <- "Private"
  over_all_public$type <- "Public"
  
  # Combine results into a single dataframe
  df_funding <- bind_rows(over_all_private, over_all_public)
  rownames(df_funding) <- NULL
  
  ## 1.6 Methodology_Type: Exogenous Eligibility vs Other ---------
  
  table(df_employment$Methodology_Type)
  
  # Filter data for exogenous eligibility
  df_employment_exog <- df_employment %>% 
    filter(Methodology_Type == "Exogenous eligibility")
  
  # Fit the model for exogenous eligibility using baggr
  set.seed(426) 
  fit_exog <- baggr(df_employment_exog, 
                       model = "rubin", 
                       pooling = "partial",
                       prior_hypermean = normal(0, 100), 
                       prior_hypersd = normal(0, 100),
                       iter = 5000, 
                       warmup = 3000,
                       effect = "MD", 
                       control = list(adapt_delta = 0.999, max_treedepth = 15))
  
  # Summarize the effects for exogenous eligibility
  effects_summary_exog <- data.frame(summary(fit_exog$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
  effects_summary_exog$Author <- fit_exog$data$Author
                                        
  # Add Average Effects (mu and tau)
  over_all_exog <- data.frame(summary(fit_exog$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
                                                                       
 # Filter data by methodology
 df_employment_other <- df_employment %>% 
   filter(Methodology_Type == "Other methodology")
 
 # Fit the model for other methodology using baggr
 set.seed(426) 
 fit_other <- baggr(df_employment_other, 
                  model = "rubin", 
                  pooling = "partial",
                  prior_hypermean = normal(0, 100), 
                  prior_hypersd = normal(0, 100),
                  iter = 5000, 
                  warmup = 3000,
                  effect = "MD", 
                  control = list(adapt_delta = 0.999, max_treedepth = 15))
 
 # Summarize the effects for other methodologies
 effects_summary_other <- data.frame(summary(fit_other$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
 effects_summary_other$Author <- fit_other$data$Author
                                   
 # Add Average Effects (mu and tau)
 over_all_other <- data.frame(summary(fit_other$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
                                                              
 # Label the types for clarity
 over_all_exog$type <- "Exogenous eligibility"
 over_all_other$type <- "Other methodologies"
                                                              
 # Combine results into a single dataframe
 df_methodology <- bind_rows(over_all_exog, over_all_other)
 rownames(df_methodology) <- NULL                                                                    
  
  
  

  # Building graphs for panels A, B, C, D in the subgroup analysis
  
  # Calculate the global range for the x-axis
  x_min_AC <- min(c(df_guarantee$X2.5.,df_size$X2.5. ), na.rm = TRUE)
  x_min_BD <- min(c(df_lender$X2.5., df_income$X2.5.), na.rm = TRUE)
  x_max_AC <- max(c(df_guarantee$X97.5., df_size$X97.5.), na.rm = TRUE)
  x_max_BD <- max(c(df_lender$X97.5., df_size$X97.5.), na.rm = TRUE)
  
  # Ensure the range includes 0
  x_min_AC <- min(x_min_AC, 0)
  x_min_BD <- min(x_min_BD, 0)
  x_max_AC <- max(x_max_AC, 0)
  x_max_BD <- max(x_max_BD, 0)
  
  
  # Graph p1
  
  p1 <- ggplot(df_guarantee, aes(x = mean, y = type)) +
    geom_point(size = 3, color = "#4682B4") +
    geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4") +
    geom_vline(xintercept = 0, linetype = "dashed", color = "red", size = 1) +
    geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1, size = 5) +
    labs(title = "", x = "", y = "") +
    scale_x_continuous(
      limits = c(x_min_AC, x_max_AC), 
      breaks = sort(unique(c(seq(floor(x_min_AC), ceiling(x_max_AC), by = 10), 0))) 
    ) +
    theme_classic() +
    theme(
      legend.position = "none",
      plot.margin = margin(l = 50),  
      axis.text.y = element_text(size = 17),  
      axis.text.x = element_text(size = 14)   
    )
  
  
  # Graph p2
  p2 <- ggplot(df_lender, aes(x = mean, y = type)) +
    geom_point(size = 3, color = "#4682B4") +
    geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4") +
    geom_vline(xintercept = 0, linetype = "dashed", color = "red", size = 1) +
    geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1, size = 5) +
    labs(title = "", x = "", y = "") +
    scale_x_continuous(
      limits = c(x_min_BD, x_max_BD), 
      breaks = sort(unique(c(seq(floor(x_min_BD), ceiling(x_max_BD), by = 10), 0))) # Añade el 0 explícitamente
    ) +
    theme_classic() +
    theme(
      legend.position = "none",
      plot.margin = margin(l = 25),  
      axis.text.y = element_text(size = 17),  
      axis.text.x = element_text(size = 14)   
    )
  
  
  # Graph p3
  
  p3 <- ggplot(df_size, aes(x = mean, y = type)) +
    geom_point(size = 3, color = "#4682B4") +
    geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4") +
    geom_vline(xintercept = 0, linetype = "dashed", color = "red", size = 1) +
    geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1, size = 5) +
    labs(title = "", x = "", y = "") +
    scale_x_continuous(
      limits = c(x_min_AC, x_max_AC), 
      breaks = sort(unique(c(seq(floor(x_min_AC), ceiling(x_max_AC), by = 10), 0))) # Añade el 0 explícitamente
    ) +
    theme_classic() +
    theme(
      legend.position = "none",
      plot.margin = margin(l = 0),  
      axis.text.y = element_text(size = 17),  
      axis.text.x = element_text(size = 14)   
    )
  
  
  # Graph p4
  
  p4 <- ggplot(df_income, aes(x = mean, y = type)) +
    geom_point(size = 3, color = "#4682B4") +
    geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4") +
    geom_vline(xintercept = 0, linetype = "dashed", color = "red", size = 1) +
    geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1, size = 5) +
    labs(title = "", x = "", y = "") +
    scale_x_continuous(
      limits = c(x_min_BD, x_max_BD), 
      breaks = sort(unique(c(seq(floor(x_min_BD), ceiling(x_max_BD), by = 10), 0))) # Añade el 0 explícitamente
    ) +
    theme_classic() +
    theme(
      legend.position = "none",
      plot.margin = margin(l = -20),  
      axis.text.y = element_text(size = 17),  
      axis.text.x = element_text(size = 14)   
    )
  
  
  # Add a 'group' column to identify the source category of each subset
  df_guarantee$group <- "Guarantee"
  df_lender$group    <- "Lender Type"
  df_size$group      <- "Firm Size"
  df_income$group    <- "Income Group"
  
  # Combine all data frames into a single data frame
  df_subgroup <- rbind(df_guarantee, df_lender, df_size, df_income)
  
  # Write the Excel file for the subgroup analysis with Employment as main outcome
  write.xlsx(df_subgroup, file.path(path, "Outputs/Employment/Df_Subgroup_Employment.xlsx"))

  ###### Figure 7: --------------------
  # Arrange the plots in a 2x2 grid
  png(
    filename = file.path(path, "Outputs/Employment/fig7_Subgroup_Employment.png"),
    width = 18.5,  # Width in inches
    height = 15.5, # Height in inches
    units = "in",  # Units (inches)
    res = 600      # Resolution (dots per inch)
  )
  
  ggarrange(
    p1, p2, p3, p4,
    nrow = 2, ncol = 2,
    widths = c(1, 1),
    labels = c("A. Guaranteed vs. Non-Guaranteed Loans", "B. Financial Institution", "                 C. Firm Size", "D. Country Income Level"),  # Labels for each panel
    font.label = list(size = 20, color = "black", face = "bold") ,label.y = 1.013 # Estilo de las etiquetas
  )
  
  # Close the graphics device (after creating the plot)
  dev.off()
  
  
  
###### Appendix Figure A5: --------------------
  png(
    filename = file.path(path, "Outputs/Employment/figA5_Annexes_Employment.png"),
    width = 6,   # Width in inches
    height = 4,  # Height in inches
    units = "in",  # Units (inches)
    res = 600      # Resolution (dots per inch)
  )

ggplot(df_funding, aes(x = mean, y = type)) +
  geom_point(size = 3, color = "#4682B4") +
  geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4") +
  geom_vline(xintercept = 0, linetype = "dashed", color = "red", size = 1) +
  geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1, size = 5) +
  labs(title = "", x = "", y = "") +
  scale_x_continuous(
    breaks = scales::breaks_width(10)
  ) +
  theme_classic() +
  theme(
    legend.position = "none",
    axis.text.y = element_text(size = 17),
    axis.text.x = element_text(size = 14)
  )

# Close the graphics device (after creating the plot)
dev.off()

###### Appendix Figure A6: --------------------

t1 <- ggplot(df_median, aes(x = mean, y = type)) +
  geom_point(size = 3, color = "#4682B4") +
  geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4") +
  geom_vline(xintercept = 0, linetype = "dashed", color = "red", size = 1) +
  geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1, size = 5) +
  labs(title = "", x = "", y = "") +
  scale_x_continuous(
    breaks = scales::breaks_width(10)
  ) +
  theme_classic() +
  theme(
    legend.position = "none",
    axis.text.y = element_text(size = 17),  
    axis.text.x = element_text(size = 14)
  )

t2 <- ggplot(df_1500, aes(x = mean, y = type)) +
  geom_point(size = 3, color = "#4682B4") +
  geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4") +
  geom_vline(xintercept = 0, linetype = "dashed", color = "red", size = 1) +
  geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1, size = 5) +
  labs(title = "", x = "", y = "") +
  scale_x_continuous(
    breaks = scales::breaks_width(10)
  ) +
  theme_classic() +
  theme(
    legend.position = "none",
    axis.text.y = element_text(size = 17),  
    axis.text.x = element_text(size = 14)
  )

# Graph on Journal Quality to the Annexes
# Arrange the plots in a 2x2 grid
png(
  filename = file.path(path, "Outputs/Employment/figA6_JournalQ_Employment.png"),
  width = 18.5,  # Width in inches
  height = 8,    # Height in inches
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

ggarrange(
  t1, t2,
  nrow = 1, ncol = 2,
  widths = c(1, 1),
  labels = c("A. Median", "B. Scimago 1500", "                 C. Firm Size"),  # Labels for each panel
  font.label = list(size = 20, color = "black", face = "bold") ,label.y = 1.013 # Estilo de las etiquetas
)

# Close the graphics device (after creating the plot)
dev.off()

###### Appendix Figure A7: Graph methodology --------------------

png(
  filename = file.path(path, "Outputs/Employment/figA7_Methodology.png"),
  width = 6,   # Width in inches
  height = 4,  # Height in inches
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

  ggplot(df_methodology, aes(x = mean, y = type)) +
  geom_point(size = 3, color = "#4682B4") +
  geom_errorbarh(aes(xmin = X2.5., xmax = X97.5.), height = 0.2, color = "#4682B4", linewidth = 1) +
  geom_vline(xintercept = 0, linetype = "dashed", color = "red", linewidth = 1) +
  geom_text(aes(label = sprintf("%.1f", mean)), vjust = -1.5, size = 5, color = "black") +
  labs(title = "", x = "Effect Size", y = "") +
  scale_x_continuous(
    limits = c(-1, max(df_methodology$X97.5.)), 
    breaks = sort(unique(c(seq(floor(min(df_methodology$X2.5.)), 
                               ceiling(max(df_methodology$X97.5.)), 
                               by = 10), 0)))) +  # <- Paréntesis extra aquí
  theme_classic() +
  theme(
    legend.position = "none",
    plot.margin = margin(l = 20, r = 20, t = 10, b = 10),  
    axis.text.y = element_text(size = 17),  
    axis.text.x = element_text(size = 14),
    axis.title.x = element_text(size = 14, margin = margin(t = 10))
  )

# Close the graphics device (after creating the plot)
dev.off()

#### 2. Robustness Checks: Different priors ---------------
set.seed(426)  
fit_n <- baggr(df_employment, model = "rubin", pooling = "partial", 
               prior_hypermean = normal(0, 10), prior_hypersd = normal(0, 100), 
               effect = "MD", control = list(adapt_delta = 0.99))
set.seed(426)  
fit_u <- baggr(df_employment, model = "rubin", pooling = "partial", 
               prior_hypermean = uniform(-100, 100), prior_hypersd = uniform(0, 100), 
               effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))
set.seed(426)  
fit_c <- baggr(df_employment, model = "rubin", pooling = "partial", 
               prior_hypermean = cauchy(0, 25), prior_hypersd = cauchy(0, 25), 
               effect = "MD", control = list(adapt_delta = 0.99, max_treedepth = 15))


# Comparing models
bgc <- baggr_compare("Base scenario (BHM)" = fit, 
                     "Cauchy (BHM)" = fit_c, 
                     "Normal (BHM)" = fit_n, 
                     "Uniform (BHM)" = fit_u, prob = c(0.90,0.95))


# Preparing data frame for a forest plot comparing different priors and the REML estimate
df_plot<-as.data.frame(bgc$mean_trt)
df_plot$Type_effect<-rownames(df_plot)

rownames(df_plot)<-NULL
df_plot[nrow(df_plot) + 1, ] <- c(
  meta_summary_REML$Lower_CI_90[meta_summary_REML$Study=="Average Effect"], #5%
  meta_summary_REML$Lower_CI_95[meta_summary_REML$Study=="Average Effect"], #2.5%
  meta_summary_REML$Estimate[meta_summary_REML$Study=="Average Effect"],    #mean
  meta_summary_REML$Upper_CI_90[meta_summary_REML$Study=="Average Effect"], #95%
  meta_summary_REML$Upper_CI_95[meta_summary_REML$Study=="Average Effect"], #97.5%
  NA,              # Upper CI 90%
  meta_summary_REML$SE[meta_summary_REML$Study=="Average Effect"],              # sd
  "REML"                       # REML
)

colnames(df_plot)<-c("lower_90","lower_95" ,"mean","upper_90","upper_95","median","sd","Type_effect")      

df_plot <- df_plot %>%
  mutate(across(c(lower_90,lower_95, mean, upper_90,upper_95, median, sd), as.numeric))

df_plot$Type_effect[df_plot$Type_effect=="Base scenario"]<-"Base scenario (BHM)"
df_plot$Type_effect <- factor(df_plot$Type_effect, levels = c("Base scenario (BHM)", "Cauchy (BHM)", "Normal (BHM)", "Uniform (BHM)","REML"))

# Write the Excel file for the Employment outcome with Different Priors
write.xlsx(df_plot, file.path(path, "Outputs/Employment/Different_Priors_Employment.xlsx"))

###### Appendix Figure A2: --------------------
png(
  filename = file.path(path, "Outputs/Employment/figA2_Priors_Employment.png"),
  width = 6,   # Width in inches
  height = 4,  # Height in inches
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

# Create the coef plot
ggplot(df_plot, aes(x = mean, y = Type_effect)) +
  # 1. Reference line for base scenario (GREEN) - FIRST LAYER
  geom_vline(
    xintercept = df_plot$mean[df_plot$Type_effect == "Base scenario (BHM)"], 
    linetype = "dashed", 
    color = "forestgreen", 
    size = 0.8
  ) +
  
  # 2. IC 95% (AZUL) - SEGUNDA CAPA
  geom_errorbarh(
    aes(xmin = lower_95, xmax = upper_95), 
    height = 0.15, 
    color = "#4682B4",  
    size = 0.6,
    position = position_nudge(y = 0.11)  # Pequeño desplazamiento hacia arriba
  ) +
  
  # Center point for 95% CI (BLUE)
  geom_point(
    size = 2, 
    color = "#4682B4",
    position = position_nudge(y = 0.11)
  ) +
  
  # 3. 90% CI (GRAY) - THIRD LAYER (topmost)
  geom_errorbarh(
    aes(xmin = lower_90, xmax = upper_90), 
    height = 0.15, 
    color = "#A9A9A9",  
    size = 0.6,
    position = position_nudge(y = -0.07)  # Desplazamiento hacia abajo
  ) +
  
  # Points for 90% CI (GRAY)
  geom_point(
    size = 2, 
    color = "#A9A9A9",
    position = position_nudge(y = -0.07)
  ) +
  
  # Vertical reference line at 0 (neutral)
  geom_vline(xintercept = 0, linetype = "solid", color = "gray", size = 0.5) +
  
  # Mean value labels
  geom_text(
    aes(label = sprintf("%.1f", mean)), 
    vjust = -0.8,
    hjust = -0.1, 
    size = 2.5,
    position = position_nudge(y = 0.1)
  ) +
  
  labs(x = "Effect Size", y = "") +
  scale_x_continuous(
    breaks = seq(
      floor(min(df_plot$lower_95)/10)*10,
      ceiling(max(df_plot$upper_95)/10)*10,
      by = 10
    ),
    limits = c(
      floor(min(df_plot$lower_95)/10)*10,
      ceiling(max(df_plot$upper_95)/10)*10
    ),
    expand = expansion(mult = 0.05)
  ) +
  theme_classic() +
  theme(
    legend.position = "none",
    axis.text = element_text(size = 10, colour = "black"),
    axis.text.y = element_text(hjust = 0.5)
  )

# Close the graphics device (after creating the plot)
dev.off()

#### 3. Meta-regression  ---------------

#1 only lender type, Column (1) 

set.seed(426)
meta_reg1 <- baggr_compare(
  df_employment,
  covariates = c("Lender_type"),
  prior_hypermean = normal(0, 100),
  prior_hypersd = normal(0, 100),model = "rubin",
  prior_beta = normal(0, 20), 
  iter = 5000, warmup = 3500,effect = "MD",
  control = list(adapt_delta = 0.99, max_treedepth = 15)
)

coef_covariates_reg1<-meta_reg1$covariates %>% filter(model=="partial")
print(meta_reg1$mean_trt)

reg1_overall<-data.frame(meta_reg1$mean_trt)




#2  lender type, firm size. Column (2) 
set.seed(426)
meta_reg2 <- baggr_compare(
  df_employment,
  covariates = c("Lender_type","IncomeF"),
  prior_hypermean = normal(0, 100),
  prior_hypersd = normal(0, 100),model = "rubin",
  prior_beta = normal(0, 20), 
  iter = 5000, warmup = 3500,effect = "MD",
  control = list(adapt_delta = 0.99, max_treedepth = 15)
)

coef_covariates_reg2<-meta_reg2$covariates %>% filter(model=="partial")
print(meta_reg2$mean_trt)

reg2_overall<-data.frame(meta_reg2$mean_trt)



#3 lender type, firm size, Income. Column (3)
set.seed(426)
meta_reg3 <- baggr_compare(
  df_employment,
  covariates = c("Lender_type","IncomeF","Firm_Size"),
  prior_hypermean = normal(0, 100),
  prior_hypersd = normal(0, 100),model = "rubin",
  prior_beta = normal(0, 20), 
  iter = 5000, warmup = 3500,effect = "MD",
  control = list(adapt_delta = 0.99, max_treedepth = 15)
)

coef_covariates_reg3<-meta_reg3$covariates %>% filter(model=="partial")
print(meta_reg1$mean_trt)

reg3_overall<-data.frame(meta_reg3$mean_trt)


#4 Lender type, firm size, Income, guarante. Column (4)
set.seed(426)
meta_reg4 <- baggr_compare(
  df_employment,
  covariates = c("Lender_type","IncomeF","Firm_Size","Type_loan"),
  prior_hypermean = normal(0, 100),
  prior_hypersd = normal(0, 100),model = "rubin",
  prior_beta = normal(0, 20), 
  iter = 5000, warmup = 3500,effect = "MD",
  control = list(adapt_delta = 0.99, max_treedepth = 15)
)

coef_covariates_reg4<-meta_reg4$covariates %>% filter(model=="partial")
print(meta_reg4$mean_trt)

reg4_overall<-data.frame(meta_reg4$mean_trt)


# Preparing the table:

# Function to include p-values based on (t-value)
get_stars <- function(mean, sd) {
  if (is.na(mean) || is.na(sd) || sd == 0) return("")  
  t_value <- mean / sd
  if (abs(t_value) > 2.58) return("$^{***}$")  # p < 0.01
  if (abs(t_value) > 1.96) return("$^{**}$")   # p < 0.05
  if (abs(t_value) > 1.65) return("$^{*}$")    # p < 0.10
  return("")
}

# Safe function to format coefficients
safe_format <- function(value, digits) {
  if (is.na(value)) return("")
  format(round(value, digits), nsmall = digits)
}

# Table construction
data_table <- data.frame(
  Variable = c(
    "Average Effect of a Formal Loan for the Reference Group", "", 
    "Lender Type: Public Financial Institutions", "", 
    "Income Group: Developing", "",
    "Firm Size: 10 or fewer", "",
    "Loan Type: Non-Guaranteed", ""
  ),
  
  # Modelo 1 (Lender_type)
  Coef1 = c(
    paste0(safe_format(reg1_overall$mean[2], 2), 
           get_stars(reg1_overall$mean[2], reg1_overall$sd[2])), 
    paste0("(", safe_format(reg1_overall$sd[2], 2), ")"), 
    paste0(safe_format(coef_covariates_reg1$mean[1], 2),
           get_stars(coef_covariates_reg1$mean[1], coef_covariates_reg1$sd[1])),
    paste0("(", safe_format(coef_covariates_reg1$sd[1], 2), ")"),
    "", "",  # Firm Size no está en Modelo 1
    "", "",  # Income no está en Modelo 1
    "", ""   # Loan Type no está en Modelo 1
  ),
  
  # Modelo 2 (Lender_type + Firm_Size)
  Coef2 = c(
    paste0(safe_format(reg2_overall$mean[2], 2),
           get_stars(reg2_overall$mean[2], reg2_overall$sd[2])),
    paste0("(", safe_format(reg2_overall$sd[2], 2), ")"), 
    paste0(safe_format(coef_covariates_reg2$mean[1], 2),
           get_stars(coef_covariates_reg2$mean[1], coef_covariates_reg2$sd[1])),
    paste0("(", safe_format(coef_covariates_reg2$sd[1], 2), ")"),
    paste0(safe_format(coef_covariates_reg2$mean[2], 2),
           get_stars(coef_covariates_reg2$mean[2], coef_covariates_reg2$sd[2])),
    paste0("(", safe_format(coef_covariates_reg2$sd[2], 2), ")"),
    "", "",  # Income no está en Modelo 2
    "", ""   # Loan Type no está en Modelo 2
  ),
  
  # Modelo 3 (Lender_type + Firm_Size + IncomeF)
  Coef3 = c(
    paste0(safe_format(reg3_overall$mean[2], 2),
           get_stars(reg3_overall$mean[2], reg3_overall$sd[2])),
    paste0("(", safe_format(reg3_overall$sd[2], 2), ")"), 
    paste0(safe_format(coef_covariates_reg3$mean[1], 2),
           get_stars(coef_covariates_reg3$mean[1], coef_covariates_reg3$sd[1])),
    paste0("(", safe_format(coef_covariates_reg3$sd[1], 2), ")"),
    paste0(safe_format(coef_covariates_reg3$mean[2], 2),
           get_stars(coef_covariates_reg3$mean[2], coef_covariates_reg3$sd[2])),
    paste0("(", safe_format(coef_covariates_reg3$sd[2], 2), ")"),
    paste0(safe_format(coef_covariates_reg3$mean[3], 2),
           get_stars(coef_covariates_reg3$mean[3], coef_covariates_reg3$sd[3])),
    paste0("(", safe_format(coef_covariates_reg3$sd[3], 2), ")"),
    "", ""   # Loan Type no está en Modelo 3
  ),
  
  # Modelo 4 (Lender_type + Firm_Size + IncomeF + Type_loan)
  Coef4 = c(
    paste0(safe_format(reg4_overall$mean[2], 2),
           get_stars(reg4_overall$mean[2], reg4_overall$sd[2])),
    paste0("(", safe_format(reg4_overall$sd[2], 2), ")"), 
    paste0(safe_format(coef_covariates_reg4$mean[1], 2),
           get_stars(coef_covariates_reg4$mean[1], coef_covariates_reg4$sd[1])),
    paste0("(", safe_format(coef_covariates_reg4$sd[1], 2), ")"),
    paste0(safe_format(coef_covariates_reg4$mean[2], 2),
           get_stars(coef_covariates_reg4$mean[2], coef_covariates_reg4$sd[2])),
    paste0("(", safe_format(coef_covariates_reg4$sd[2], 2), ")"),
    paste0(safe_format(coef_covariates_reg4$mean[3], 2),
           get_stars(coef_covariates_reg4$mean[3], coef_covariates_reg4$sd[3])),
    paste0("(", safe_format(coef_covariates_reg4$sd[3], 2), ")"),
    paste0(safe_format(coef_covariates_reg4$mean[4], 2),
           get_stars(coef_covariates_reg4$mean[4], coef_covariates_reg4$sd[4])),
    paste0("(", safe_format(coef_covariates_reg4$sd[4], 2), ")")
  )
)

# Names of Columns 
colnames(data_table) <- c("Variable", "Model 1", "Model 2", "Model 3", "Model 4")

# Show table
print(data_table)

#Export Meta-regression 
write_xlsx(data_table, file.path(path, "Outputs/Employment/Tab_2_Meta_Regression.xlsx"))

#### 4. Predictive distribution  ---------------

set.seed(426)  
PD<-effect_plot("Predictive distribution"=fit)

# Predicting Probability of a Negative Effect (share of negative values)
prob_negativo <- mean(PD$data$value < 0)

# Calculate density values
density_data <- ggplot_build(
  ggplot(PD$data, aes(x = value)) +
    geom_density(fill = "grey", alpha = 0.7, color = "black")
)$data[[1]]

# Write the Excel file for Employment predictive distribution
write_xlsx(PD$data, file.path(path, "Outputs/Employment/Employment_predictive_distribution.xlsx"))

###### Figure 2: --------------------
# Open a graphics device (before creating the plot)
png(
  filename = file.path(path, "Outputs/Employment/fig2_predictive_distribution.png"),
  width = 17.2,  # Width in inches
  height = 8.8,  # Height in inches
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

# Create the predictive distribution plot
ggplot(PD$data, aes(x = value)) +
  geom_density(fill = "grey", alpha = 0.7, color = "black") +
  geom_vline(xintercept = mean(PD$data$value), linetype = "dashed", color = "forestgreen", size = 1) +  
  #geom_vline(xintercept = 0,  color = "black", linetype = "dashed", size = 1) +  
  geom_ribbon(data = subset(density_data, x < 0), aes(x = x, ymin = 0, ymax = y), fill = "red", alpha = 0.5) +
  annotate("text", x = mean(PD$data$value), y = 0.05, label = paste("Mean = ", round(mean(PD$data$value), 1),"%"), color = "forestgreen", hjust = -0.2, size=8) +  
  annotate("text", x = -14.5, y = 0.015, label = paste("P(Negative Effect) = ", round(prob_negativo, 3)*100,"%"), color = "black", size = 9) +  
  annotate("text", x = 42, y = 0.015, label = paste("P(Positive Effect) = ", round(1 - prob_negativo, 3)*100,"%"), color = "black", size = 9) +  
  theme_classic() +
  labs(title = "", x = "Effect Size", y = "Density") +
  expand_limits(x = 0) +  # Asegura que el eje X incluya el 0
  scale_y_continuous(expand = expansion(mult = c(0, 0.05)))+ # Evita separación innecesaria en Y-axis
  theme(
    axis.title.x = element_text(size = 17),   # Tamaño de las etiquetas del eje X
    axis.title.y = element_text(size = 17),   # Tamaño de las etiquetas del eje Y
    axis.text.x = element_text(size = 14),    # Tamaño de los números en el eje X
    axis.text.y = element_text(size = 12)     # Tamaño de los números en el eje Y
  )

dev.off()  #close the png file

# CI 90%
quantiles <- quantile(PD$data$value, probs = c(0.025,0.05, 0.95, 0.975))

# Show the quantiles (Confidence Interval)
quantiles

IC_Employment<-as.data.frame(quantiles) 


