# # Reproducibility Package
# # 02.3 Data Analysis -Profit


## NON-BAYESIAN ESTIMATION
## REML 95--------------------

REML <- metagen(
  TE = `beta final`,
  seTE = `SE beta final`,
  studlab = Author,
  data = df_profit,
  sm = "MD",
  random = TRUE,
  common = FALSE,
  method.tau = "REML",
  method.random.ci = "HK",
  level = 0.95,
  level.ma  = 0.95,
  level.hetstat= 0.95,
  title = "REML"
)


# Calculate the weights for the plot
weights_random <- 100 * REML$w.random / sum(REML$w.random)

# Create a summary of the results
meta_summary_REML <- data.frame(
  Study = REML$studlab,
  Estimate = REML$TE,
  SE = REML$seTE,
  Lower_CI_95 = REML$lower,
  Upper_CI_95 = REML$upper,
  p_value = REML$pval,
  Weight_Random = round(weights_random, 2)  # Round to two decimal places
)

# Add a row with the overall result (Overall 90%)
meta_summary_REML[nrow(meta_summary_REML) + 1, ] <- c(
  "Average Effect",                        # Study
  REML$TE.random,                 # Estimate
  REML$seTE.random,               # SE
  REML$lower.random,              # Lower CI 90%
  REML$upper.random,              # Upper CI 90%
  REML$pval.random,              # p-value
  NA                                    # Weight (Overall has no weight)
)


## REML 90--------------------

REML_90 <- metagen(
  TE = `beta final`,
  seTE = `SE beta final`,
  studlab = Author,
  data = df_profit,
  sm = "MD",
  random = TRUE,
  common = FALSE,
  method.tau = "REML",
  method.random.ci = "HK",
  level = 0.90,
  level.ma  = 0.90,
  level.hetstat= 0.90,
  title = "REML"
)

# Calculate the weights for the plot
weights_random <- 100 * REML_90$w.random / sum(REML_90$w.random)

# Create a summary of the results
meta_summary_REML_90 <- data.frame(
  Study = REML_90$studlab,
  Estimate = REML_90$TE,
  SE = REML_90$seTE,
  Lower_CI_90 = REML_90$lower,
  Upper_CI_90 = REML_90$upper,
  p_value = REML_90$pval,
  Weight_Random = round(weights_random, 2)   # Round to two decimal places
)

# Add a row with the overall result (Overall 90%)
meta_summary_REML_90[nrow(meta_summary_REML_90) + 1, ] <- c(
  "Average Effect",                        # sTUDY
  REML_90$TE.random,                 # Estimate
  REML_90$seTE.random,               # SE
  REML_90$lower.random,              # Lower CI 90%
  REML_90$upper.random,              # Upper CI 90%
  REML_90$pval.random,              # p-value
  NA                                    # Weight (Overall has no weight)
)

meta_summary_REML<-merge(meta_summary_REML, select(meta_summary_REML_90,c(Study,Lower_CI_90,Upper_CI_90)), by="Study")

#Generate excel file with BHM Estimates
write_xlsx(meta_summary_REML, file.path(path, "Outputs/Profit/REML_Profit.xlsx"))

## BAYESIAN ESTIMATION
# Baggr (Rachael Meager, Witold Wiecek)--------------------

set.seed(426)  
fit <- baggr(df_profit, model = "rubin", pooling = "partial",
             prior_hypermean = normal(0, 100), 
             prior_hypersd = normal(0, 100),  # Usar normal para la SD
             iter = 5000, warmup = 3500,
             effect = "MD", control = list(adapt_delta = 0.995, max_treedepth = 15))


effects_summary <- data.frame(summary(fit$fit, pars = c("theta_k"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary$Author<-fit$data$Author
effects_summary$Region<-fit$data$Region
effects_summary$Income_group<-fit$data$Income_group
effects_summary<-effects_summary %>% arrange(-mean)
over_all<-data.frame(summary(fit$fit, pars = c("mu"), prob = c(0.025,0.05,0.95,0.975))$summary)
effects_summary<-bind_rows(effects_summary,over_all)
effects_summary$Author[nrow(effects_summary)] <- "Average Effect" 



#Generate excel file with BHM Estimates
write_xlsx(effects_summary, file.path(path, "Outputs/Profit/BHM_Profit.xlsx"))

###### Figure 5: --------------------
# Open a graphics device (before creating the plot)
png(
  filename = file.path(path, "Outputs/Profit/fig5_forestplot_Profit.png"),
  width = 22.2,  # Width in inches
  height = 6.5,  # Height in inches
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

# Prepare the data
mean_values <- effects_summary$mean
lower95 <- effects_summary$X2.5.
upper95 <- effects_summary$X97.5.

# Build the label table
tabletext <- cbind(
  c("Author", effects_summary$Author),
  c("Region", as.character(effects_summary$Region)),
  c("Estimate", sprintf("%.1f", mean_values)),
  c("95% CI", sprintf("[%.1f, %.1f]", lower95, upper95))
)

# Identify the Average Effect (mu[1])
is_summary <- c(TRUE, rep(FALSE, nrow(effects_summary)))

# Dynamically calculate the xticks
x_ticks <- seq(floor(min(effects_summary$X2.5., na.rm = TRUE) / 10) * 10,
               ceiling(max(effects_summary$X97.5., na.rm = TRUE) / 10) * 10,
               by = 10)

# Text and fonts
txt_size <- 1.4  # Uniform size for everything
forestplot(
  labeltext = tabletext,
  mean = cbind(c(NA, mean_values)),
  lower = cbind(c(NA, lower95)),
  upper = cbind(c(NA, upper95)),
  colgap = unit(c(20), "mm"),
  col = fpColors(
    box = c("#4682B4", "#A9A9A9"),
    lines = c("#4682B4", "#A9A9A9"),
    summary = "navy"
  ),
  
  boxsize = 0.2,
  lineheight = "auto",
  graphwidth = unit(20, "cm"), #17
  mar = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
  
  fn.ci_norm = rep(list(fpDrawCircleCI), nrow(effects_summary) + 1), # Corregido aquí
  ci.vertices = TRUE,
  ci.vertices.height = 0.25,
  
  txt_gp = fpTxtGp(
    label = gpar(cex = 1.7),
    ticks = gpar(cex = 1.2),
    xlab = gpar(cex = 1.5),
    title = gpar(cex = txt_size),
    legend = gpar(cex = txt_size)
  ),
  
  xlab = "Effect Size",
  zero = 0,
  is.summary = is_summary,
  xticks = x_ticks,
  grid = structure(effects_summary$mean[effects_summary$Author=='Average Effect'], gp = gpar(col = c("forestgreen"), lty = 2, lwd = 1.5)),
)
# Close the graphics device (after creating the plot)
dev.off()


#### 1. Robustness Checks: Different priors ---------------

set.seed(426)  
fit_n <- baggr(df_profit, model = "rubin", pooling = "partial", 
               prior_hypermean = normal(0, 40), prior_hypersd = normal(0, 100), 
               effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))
set.seed(426)  
fit_u <- baggr(df_profit, model = "rubin", pooling = "partial", 
               prior_hypermean = uniform(-100, 100), prior_hypersd = normal(0, 100), 
               effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))
set.seed(426)  
fit_c <- baggr(df_profit, model = "rubin", pooling = "partial", 
               prior_hypermean = cauchy(0, 25), prior_hypersd = cauchy(0, 25), 
               effect = "MD", control = list(adapt_delta = 0.999, max_treedepth = 15))


# Comparing models
bgc <- baggr_compare("Base scenario (BHM)" = fit, 
                     "Cauchy (BHM)" = fit_c, 
                     "Normal (BHM)" = fit_n, 
                     "Uniform (BHM)" = fit_u, prob = c(0.90,0.95))


# Preparing data frame for a forest plot comparing different priors and the REML estimate
df_plot<-as.data.frame(bgc$mean_trt)
df_plot$Type_effect<-rownames(df_plot)

rownames(df_plot)<-NULL
df_plot[nrow(df_plot) + 1, ] <- c(
  meta_summary_REML$Lower_CI_90[meta_summary_REML$Study=="Average Effect"], #5%
  meta_summary_REML$Lower_CI_95[meta_summary_REML$Study=="Average Effect"], #2.5%
  meta_summary_REML$Estimate[meta_summary_REML$Study=="Average Effect"],    #mean
  meta_summary_REML$Upper_CI_90[meta_summary_REML$Study=="Average Effect"], #95%
  meta_summary_REML$Upper_CI_95[meta_summary_REML$Study=="Average Effect"], #97.5%
  NA,              # Upper CI 90%
  meta_summary_REML$SE[meta_summary_REML$Study=="Average Effect"],              # sd
  "REML"                       # REML
)

colnames(df_plot)<-c("lower_90","lower_95" ,"mean","upper_90","upper_95","median","sd","Type_effect")      

df_plot <- df_plot %>%
  mutate(across(c(lower_90,lower_95, mean, upper_90,upper_95, median, sd), as.numeric))

df_plot$Type_effect[df_plot$Type_effect=="Base scenario"]<-"Base scenario (BHM)"
df_plot$Type_effect <- factor(df_plot$Type_effect, levels = c("Base scenario (BHM)", "Cauchy (BHM)", "Normal (BHM)", "Uniform (BHM)","REML"))

# Write the Excel file for the Profit outcome with Different Priors
write_xlsx(df_plot, file.path(path, "Outputs/Profit/Different_Priors_Profit.xlsx"))

###### Appendix Figure A4: --------------------

png(
  filename = file.path(path, "Outputs/Profit/figA4_Priors_Profit.png"),
  width = 6,   # Width in inches
  height = 4,  # Height in inches
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

# Create the coef plot
ggplot(df_plot, aes(x = mean, y = Type_effect)) +
  # 1. Reference line for base scenario (GREEN) - FIRST LAYER
  geom_vline(
    xintercept = df_plot$mean[df_plot$Type_effect == "Base scenario (BHM)"], 
    linetype = "dashed", 
    color = "forestgreen", 
    size = 0.8
  ) +
  
  # 2. 95% CI (BLUE) - SECOND LAYER
  geom_errorbarh(
    aes(xmin = lower_95, xmax = upper_95), 
    height = 0.15, 
    color = "#4682B4",  
    size = 0.6,
    position = position_nudge(y = 0.11)  # Small upward shift
  ) +
  
  # Center point for 95% CI (BLUE)
  geom_point(
    size = 2, 
    color = "#4682B4",
    position = position_nudge(y = 0.11)
  ) +
  
  # 3. 90% CI (GRAY) - THIRD LAYER (topmost)
  geom_errorbarh(
    aes(xmin = lower_90, xmax = upper_90), 
    height = 0.15, 
    color = "#A9A9A9",  
    size = 0.6,
    position = position_nudge(y = -0.07)  # Downward shift
  ) +
  
  # Points for 90% CI (GRAY)
  geom_point(
    size = 2, 
    color = "#A9A9A9",
    position = position_nudge(y = -0.07)
  ) +
  
  # Vertical reference line at 0 (neutral)
  geom_vline(xintercept = 0, linetype = "solid", color = "gray", size = 0.5) +
  
  # Mean value labels
  geom_text(
    aes(label = sprintf("%.1f", mean)), 
    vjust = -0.8,
    hjust = -0.1, 
    size = 2.5,
    position = position_nudge(y = 0.1)
  ) +
  
  labs(x = "Effect Size", y = "") +
  scale_x_continuous(
    breaks = seq(
      floor(min(df_plot$lower_95)/10)*10,
      ceiling(max(df_plot$upper_95)/10)*10,
      by = 10
    ),
    limits = c(
      floor(min(df_plot$lower_95)/10)*10,
      ceiling(max(df_plot$upper_95)/10)*10
    ),
    expand = expansion(mult = 0.05)
  ) +
  theme_classic() +
  theme(
    legend.position = "none",
    axis.text = element_text(size = 10, colour = "black"),
    axis.text.y = element_text(hjust = 0.5)
  )

# Close the graphics device (after creating the plot)
dev.off()


#### 2. Predictive distribution  ---------------

set.seed(426)  
PD<-effect_plot("Predictive distribution"=fit)

# Cálculo de la probabilidad negativa (fracción de los valores negativos)
prob_negativo <- mean(PD$data$value < 0)

# Calcular los valores de densidad
density_data <- ggplot_build(
  ggplot(PD$data, aes(x = value)) +
    geom_density(fill = "grey", alpha = 0.7, color = "black")
)$data[[1]]

# Write the Excel file for Profit predictive distribution
write_xlsx(PD$data, file.path(path, "Outputs/Profit/Profit_predictive_distribution.xlsx"))

###### Figure 6: --------------------
# Open a graphics device (before creating the plot)
png(
  filename = file.path(path, "Outputs/Profit/fig6_predictive_distribution.png"),
  width = 17.2,  # Width in inches
  height = 8.8,  # Height in inches
  units = "in",  # Units (inches)
  res = 600      # Resolution (dots per inch)
)

# Create the predictive distribution plot
ggplot(PD$data, aes(x = value)) +
  geom_density(fill = "grey", alpha = 0.7, color = "black") +
  geom_vline(xintercept = mean(PD$data$value), linetype = "dashed", color = "forestgreen", size = 1) +  
  #geom_vline(xintercept = 0,  color = "black", linetype = "dashed", size = 1) +  
  geom_ribbon(data = subset(density_data, x < 0), aes(x = x, ymin = 0, ymax = y), fill = "red", alpha = 0.5) +
  annotate("text", x = mean(PD$data$value), y = 0.0245, label = paste("Mean = ", round(mean(PD$data$value), 1),"%"), color = "forestgreen", hjust = -0.2, size=8) +  
  annotate("text", x = -100, y = 0.0055, label = paste("P(Negative Effect) = ", round(prob_negativo, 3)*100,"%"), color = "black", size = 9) +  
  annotate("text", x = 135, y = 0.0055, label = paste("P(Positive Effect) = ", round(1 - prob_negativo, 3)*100,"%"), color = "black", size = 9) +  
  theme_classic() +
  labs(title = "", x = "Effect Size", y = "Density") +
  expand_limits(x = 0) + 
  scale_y_continuous(expand = expansion(mult = c(0, 0.02)))+ # Evita separación innecesaria en Y-axis
  theme(
    axis.title.x = element_text(size = 17),   # Tamaño de las etiquetas del eje X
    axis.title.y = element_text(size = 17),   # Tamaño de las etiquetas del eje Y
    axis.text.x = element_text(size = 14),    # Tamaño de los números en el eje X
    axis.text.y = element_text(size = 12)     # Tamaño de los números en el eje Y
  )

dev.off()  #close the png file

# CI 90%
quantiles <- quantile(PD$data$value, probs = c(0.025,0.05, 0.95, 0.975))

# Show the quantiles (Confidence Interval)
quantiles

IC_Profit<-as.data.frame(quantiles) 
